@@ -1,3 +1,3 @@
 package IO::Moose::IO_MooseTest_Bad;
 
-sub SYNTAX_ERROR {
+0;
